﻿<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="xml" encoding="UTF-8" />

<xsl:template match="/">
	<xsl:apply-templates select="mulka/export"/>
</xsl:template>

<xsl:template match="export">
	<xsl:element name="lapcombat">
		<xsl:attribute name="version">2.19</xsl:attribute>
		<xsl:attribute name="filedate"><xsl:value-of select="/mulka/export/system/date" />&#x0020;<xsl:value-of select="/mulka/export/system/time" /></xsl:attribute>
		<xsl:attribute name="type">application/x-lapcombat2</xsl:attribute>
		<xsl:apply-templates select="application"/>
		<xsl:apply-templates select="event"/>
		<xsl:apply-templates select="classes" mode="m-lap"/>
		<xsl:apply-templates select="courses" mode="m-course"/>
	</xsl:element>
</xsl:template>

<xsl:template match="application">
	<meta>
		<xsl:element name="create">
			<xsl:attribute name="application"><xsl:value-of select="name" />&#x0020;Version&#x0020;<xsl:value-of select="version" /></xsl:attribute>
			<xsl:attribute name="date"><xsl:value-of select="/mulka/export/system/date" />&#x0020;<xsl:value-of select="/mulka/export/system/time" /></xsl:attribute>
		</xsl:element>
	</meta>
</xsl:template>

<xsl:template match="event">
	<xsl:element name="event">
		<xsl:attribute name="name"><xsl:value-of select="name" /></xsl:attribute>
		<xsl:attribute name="date"><xsl:value-of select="date" /></xsl:attribute>
		<xsl:attribute name="terrain"><xsl:value-of select="terrain" /></xsl:attribute>
		<xsl:attribute name="filename"><xsl:value-of select="file-name" /></xsl:attribute>
		<xsl:attribute name="homepage"><xsl:value-of select="homepage" /></xsl:attribute>
	</xsl:element>
</xsl:template>

<xsl:template match="classes" mode="m-lap">
	<classes>
		<xsl:apply-templates select="class" mode="m-lap"/>
	</classes>
</xsl:template>

<xsl:template match="class" mode="m-lap">

	<xsl:variable name="select-course">
		<xsl:value-of select="course/@object-id" />
	</xsl:variable>

	<xsl:element name="class">
		<xsl:attribute name="name"><xsl:value-of select="name" /></xsl:attribute>

		<xsl:choose>
			<xsl:when test="$select-course = ''">
				<xsl:attribute name="controls">0</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:attribute name="controls">
					<xsl:value-of select="/mulka/export/courses/course[@object-id=$select-course]/controls/@count"/>
				</xsl:attribute>
				<xsl:attribute name="course">
					<xsl:value-of select="/mulka/export/courses/course[@object-id=$select-course]/@index"/>
				</xsl:attribute>
			</xsl:otherwise>
		</xsl:choose>

		<xsl:for-each select="result-list/competitor">
			<xsl:variable name="select-competitor">
				<xsl:value-of select="@object-id" />
			</xsl:variable>
			<xsl:apply-templates select="/mulka/export/competitors/competitor[@object-id=$select-competitor]" mode="m-lap"/>
		</xsl:for-each>
	</xsl:element>
</xsl:template>

<xsl:template match="competitor" mode="m-lap">

	<xsl:variable name="select-class">
		<xsl:value-of select="class/@object-id" />
	</xsl:variable>
	<xsl:variable name="select-course">
		<xsl:value-of select="/mulka/export/classes/class[@object-id=$select-class]/course/@object-id"/>
	</xsl:variable>

	<xsl:element name="runner">
		<xsl:attribute name="name"><xsl:value-of select="name" /></xsl:attribute>
		<xsl:attribute name="id"><xsl:value-of select="start-number" /></xsl:attribute>
		<xsl:attribute name="ecard"><xsl:value-of select="card/number" /></xsl:attribute>
		<xsl:attribute name="club"><xsl:value-of select="club" /></xsl:attribute>
		<xsl:attribute name="start"><xsl:value-of select="start-time" /></xsl:attribute>
		<xsl:attribute name="result"><xsl:value-of select="result" /></xsl:attribute>
		<xsl:attribute name="rank"><xsl:value-of select="class/@rank" /></xsl:attribute>
		<xsl:attribute name="age"><xsl:value-of select="age" /></xsl:attribute>
		<xsl:attribute name="sex"><xsl:value-of select="sex" /></xsl:attribute>

		<xsl:if test="course/@object-id = $select-course">
			<xsl:apply-templates select="course/laps/lap" mode="m-lap"/>
		</xsl:if>

	</xsl:element>
</xsl:template>

<xsl:template match="lap" mode="m-lap">
	<xsl:element name="leg">
		<xsl:attribute name="index"><xsl:value-of select="@index" /></xsl:attribute>
		<xsl:attribute name="laptime"><xsl:value-of select="." /></xsl:attribute>
	</xsl:element>
</xsl:template>

<xsl:template match="courses" mode="m-course">
	<courses>
		<xsl:apply-templates select="course" mode="m-course"/>
	</courses>
</xsl:template>

<xsl:template match="course" mode="m-course">
	<course number="{@index}" controls="{controls/@count}">
		<xsl:apply-templates select="controls" mode="m-course"/>
	</course>
</xsl:template>

<xsl:template match="controls" mode="m-course">
	<xsl:apply-templates select="control" mode="m-course"/>
</xsl:template>

<xsl:template match="control" mode="m-course">
	<control index="{@index}" unit-number="{unit}"/>
</xsl:template>

</xsl:stylesheet>


